import Link from 'next/link';
import { FootballData } from '@helpers/FootballData';
import Match from '@components/pages/Match';
import '../matchdaycard.css';


import dmetadata from '@metadata.json'
import leaguesname from '@helpers/leagues.json'


export async function generateMetadata({ params, searchParams }, parent) {

  const previousImages = (await parent).openGraph?.images || []
 
  return {
    title: (leaguesname.shorts[params.code] ?? 'European Football Leagues') + ' Fixtures and Scores | Download & Share Match Cards '+dmetadata.name,
  	description: 'Stay updated with the latest fixtures and scores of the '+(leaguesname.shorts[params.code] ?? 'European Football Leagues')+'. Share or download match-generated cards for an interactive football experience.',
  }
}


export default async function Page({ params, searchParams }) {

					const fdata = new FootballData();
					const codes = fdata.getCompitionsCodes();

						let matchday = 1;
						let outdate = false;

						const competition = await fdata.getCompition(params.code);
						try{
							if (Math.abs(competition.currentSeason?.currentMatchday-searchParams.matchday) < 3) {
								matchday = searchParams.matchday;
							}else{
								outdate = true;
								matchday = competition.currentSeason?.currentMatchday;
							}
						} catch( err ) {
							matchday = competition.currentSeason?.currentMatchday;
						}
						const mdata = await fdata.getCompitionMatchs(competition.id, matchday);
					let bgg = 'yellow';

					if(params.code === 'PL'){
						bgg = 'url("/designs/pl-design.jpeg")';
					} else if(params.code === 'CL') {
						bgg = 'url("/designs/CL.jpg")';
					} else if(params.code === 'PD') {
						bgg = 'url("/designs/PD.svg")';
					} else if(params.code === 'SA') {
						bgg = 'url("/designs/SA.svg")';
					} else if(params.code ==='BL1') {
						bgg = 'radial-gradient(circle, rgb(255, 124, 124) 0%, rgb(255, 86, 86) 14%, rgb(255, 86, 86) 15%, rgb(255, 33, 33) 48%, rgb(255, 255, 255) 100%)';
					} else if(params.code ==='FL1') {
						bgg = 'url("/designs/FL1.svg")';
					} else if(params.code ==='DED') {
						bgg = 'radial-gradient(circle, #99c1f1 0%, #8defff 14%, #bff1ff 15%, #bff1ff 48%, #fff 100%)';
					} else if(params.code === 'WC') {
						bgg = 'radial-gradient(#c7feff 0%, #ffc9c9 14%, #e9ffb9 15%, #b6ffe0 48%, #ffdbc7 100%)';
					}

		return (
					<div className="py-6" style={{ background: bgg, backgroundSize: 'cover', backgroundPosition: 'center' }}>
							<div className="container w-auto m-auto mx-4 flex flex-col sm:flex-row items-start">
									<Link href="/match-day-card" className="btn bnt-outline btn-primary">Back</Link>
									<div className="tabs tabs-boxed m-auto sm:mt-auto mt-2 w-[90%] sm:w-auto">
										{
											competition.currentSeason.currentMatchday-2>0 ? (
												<Link href={`/match-day-card/${params.code}?matchday=${competition.currentSeason.currentMatchday-2}`} className={`tab ${competition.currentSeason.currentMatchday-2==searchParams.matchday?'tab-active':' '}`}>Matchday {competition.currentSeason.currentMatchday-2}</Link> 
											):''
										}
										{
										competition.currentSeason.currentMatchday-1>0 ? (
												<Link href={`/match-day-card/${params.code}?matchday=${competition.currentSeason.currentMatchday-1}`} className={`tab ${competition.currentSeason.currentMatchday-1==searchParams.matchday?'tab-active':' '}`} >Matchday {competition.currentSeason.currentMatchday-1}</Link> 
											) :''
										}
										<Link href={`/match-day-card/${params.code}?matchday=${competition.currentSeason.currentMatchday}`} className={`tab ${competition.currentSeason.currentMatchday==searchParams.matchday?'tab-active':' '}`}>Current Matchday</Link> 
										{
											competition.currentSeason.currentMatchday+1<=38 ? (
												<Link href={`/match-day-card/${params.code}?matchday=${competition.currentSeason.currentMatchday+1}`} className={`tab ${competition.currentSeason.currentMatchday+1==searchParams.matchday?'tab-active':' '}`}>Matchday {competition.currentSeason.currentMatchday+1}</Link> 
											) :''
										}
										{
											competition.currentSeason.currentMatchday+2<=38 ? (
												<Link href={`/match-day-card/${params.code}?matchday=${competition.currentSeason.currentMatchday+2}`} className={`tab ${competition.currentSeason.currentMatchday+2==searchParams.matchday?'tab-active':' '}`}>Matchday {competition.currentSeason.currentMatchday+2}</Link> 
											) :''
										}
									</div>
							</div>
							<div className="cntainer m-auto">
								{
									outdate ? (
										<div className="alert alert-error m-[2em] w-auto">
											<svg xmlns="http://www.w3.org/2000/svg" className="stroke-current shrink-0 h-6 w-6" fill="none" viewBox="0 0 24 24"><path strokeLinecap="round" strokeLinejoin="round" strokeWidth="2" d="M10 14l2-2m0 0l2-2m-2 2l-2-2m2 2l2 2m7-2a9 9 0 11-18 0 9 9 0 0118 0z" /></svg>
											<span>Error! You trying accessing a non public data!</span>
										</div>
									) : null
								}
							</div>
							{
								mdata.matches && mdata.matches.length !== 0 ? (
									<div className="flex items-center justify-center content-center flex-wrap my-8">
										{
											mdata.matches.map((match,i)=>(
												<Match code={params.code} id={match.id} key={i} data={match} />
											))
										}
									</div>
								) : (
									<div className="container sm:mx-auto my-8 rounded-lg m-auto bg-secondary w-auto h-[20em] p-12 text-2xl font-extrabold">NOTHING FOUND!</div>
								)
							}
				</div>
    );
}
